#ifndef NT2_INCLUDE_FUNCTIONS_PREV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_PREV_HPP_INCLUDED

#include <nt2/ieee/include/functions/prev.hpp>

#endif
